@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2023 Cppcheck team.
+ * Copyright (C) 2007-2024 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,9 @@
 #include "settings.h"
 #include "fixture.h"
 #include "helpers.h"
+#include "suppressions.h"
+
+
 
 class TestSettings : public TestFixture {
 public:
@@ -31,7 +34,9 @@ private:
         TEST_CASE(simpleEnableGroup);
         TEST_CASE(loadCppcheckCfg);
         TEST_CASE(loadCppcheckCfgSafety);
+        TEST_CASE(getNameAndVersion);
         TEST_CASE(ruleTexts);
+        TEST_CASE(checkLevelDefault);
     }
 
     void simpleEnableGroup() const {
@@ -94,78 +99,78 @@ private:
     {
         {
             Settings s;
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             "{}\n");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             "{\n");
-            ASSERT_EQUALS("not a valid JSON - syntax error at line 2 near: ", s.loadCppcheckCfg());
+            ASSERT_EQUALS("not a valid JSON - syntax error at line 2 near: ", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"productName": ""}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS("", s.cppcheckCfgProductName);
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"productName": "product"}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS("product", s.cppcheckCfgProductName);
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"productName": 1}\n)");
-            ASSERT_EQUALS("'productName' is not a string", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'productName' is not a string", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"about": ""}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS("", s.cppcheckCfgAbout);
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"about": "about"}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS("about", s.cppcheckCfgAbout);
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"about": 1}\n)");
-            ASSERT_EQUALS("'about' is not a string", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'about' is not a string", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"addons": []}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(0, s.addons.size());
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"addons": 1}\n)");
-            ASSERT_EQUALS("'addons' is not an array", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'addons' is not an array", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"addons": ["addon"]}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(1, s.addons.size());
             ASSERT_EQUALS("addon", *s.addons.cbegin());
         }
@@ -173,40 +178,40 @@ private:
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"addons": [1]}\n)");
-            ASSERT_EQUALS("'addons' array entry is not a string", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'addons' array entry is not a string", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"addons": []}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(0, s.addons.size());
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"suppressions": 1}\n)");
-            ASSERT_EQUALS("'suppressions' is not an array", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'suppressions' is not an array", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"suppressions": ["id"]}\n)");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
-            ASSERT_EQUALS(1, s.nomsg.getSuppressions().size());
-            ASSERT_EQUALS("id", s.nomsg.getSuppressions().cbegin()->errorId);
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
+            ASSERT_EQUALS(1, s.supprs.nomsg.getSuppressions().size());
+            ASSERT_EQUALS("id", s.supprs.nomsg.getSuppressions().cbegin()->errorId);
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"suppressions": [""]}\n)");
-            ASSERT_EQUALS("could not parse suppression '' - Failed to add suppression. No id.", s.loadCppcheckCfg());
+            ASSERT_EQUALS("could not parse suppression '' - Failed to add suppression. No id.", Settings::loadCppcheckCfg(s, s.supprs));
         }
         {
             Settings s;
             ScopedFile file("cppcheck.cfg",
                             R"({"suppressions": [1]}\n)");
-            ASSERT_EQUALS("'suppressions' array entry is not a string", s.loadCppcheckCfg());
+            ASSERT_EQUALS("'suppressions' array entry is not a string", Settings::loadCppcheckCfg(s, s.supprs));
         }
 
         // TODO: test with FILESDIR
@@ -219,7 +224,7 @@ private:
             Settings s;
             s.safety = false;
             ScopedFile file("cppcheck.cfg", "{}");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(false, s.safety);
         }
 
@@ -227,7 +232,7 @@ private:
             Settings s;
             s.safety = true;
             ScopedFile file("cppcheck.cfg", "{\"safety\": false}");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(true, s.safety);
         }
 
@@ -235,11 +240,26 @@ private:
             Settings s;
             s.safety = false;
             ScopedFile file("cppcheck.cfg", "{\"safety\": true}");
-            ASSERT_EQUALS("", s.loadCppcheckCfg());
+            ASSERT_EQUALS("", Settings::loadCppcheckCfg(s, s.supprs));
             ASSERT_EQUALS(true, s.safety);
         }
     }
 
+    void getNameAndVersion() const
+    {
+        {
+            const auto nameVersion = Settings::getNameAndVersion("Cppcheck Premium 12.3.4");
+            ASSERT_EQUALS("Cppcheck Premium", nameVersion.first);
+            ASSERT_EQUALS("12.3.4", nameVersion.second);
+        }
+
+        {
+            const auto nameVersion = Settings::getNameAndVersion("Cppcheck Premium 12.3.4s");
+            ASSERT_EQUALS("Cppcheck Premium", nameVersion.first);
+            ASSERT_EQUALS("12.3.4s", nameVersion.second);
+        }
+    }
+
     void ruleTexts() const
     {
         Settings s;
@@ -247,6 +267,14 @@ private:
         ASSERT_EQUALS("text 1", s.getMisraRuleText("misra-c2012-1.1", "---"));
         ASSERT_EQUALS("text 2", s.getMisraRuleText("misra-c2012-1.2", "---"));
     }
+
+    void checkLevelDefault() const
+    {
+        Settings s;
+        ASSERT_EQUALS_ENUM(s.checkLevel, Settings::CheckLevel::exhaustive);
+        ASSERT_EQUALS(s.performanceValueFlowMaxIfCount, -1);
+        ASSERT_EQUALS(s.performanceValueFlowMaxSubFunctionArgs, 256);
+    }
 };
 
 REGISTER_TEST(TestSettings)
